summaryrefslogtreecommitdiff
path: root/NxWidgets/nxwm/src/cnxconsole.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'NxWidgets/nxwm/src/cnxconsole.cxx')
-rw-r--r--NxWidgets/nxwm/src/cnxconsole.cxx11
1 files changed, 7 insertions, 4 deletions
diff --git a/NxWidgets/nxwm/src/cnxconsole.cxx b/NxWidgets/nxwm/src/cnxconsole.cxx
index d4e4b15c6..a127a8a5a 100644
--- a/NxWidgets/nxwm/src/cnxconsole.cxx
+++ b/NxWidgets/nxwm/src/cnxconsole.cxx
@@ -41,6 +41,7 @@
#include "nxwmconfig.hxx"
#include "cnxconsole.hxx"
+#include "nxwmglyphs.hxx"
/********************************************************************************************
* Pre-Processor Definitions
@@ -50,6 +51,8 @@
* CNxConsole Method Implementations
********************************************************************************************/
+using namespace NxWM;
+
/**
* CNxConsole constructor
*
@@ -63,14 +66,14 @@ CNxConsole::CNxConsole(NXWidgets::INxWindow *window)
/**
* Get the icon associated with the application
*
* @return An instance if INxBitmap that may be used to rend the
* application's icon. This is an new INxBitmap instance that must
* be deleted by the caller when it is no long needed.
*/
-NXWidgets::INxBitmap *CNxConsole::getIcon(void)
+NXWidgets::IBitmap *CNxConsole::getIcon(void)
{
NXWidgets::CRlePaletteBitmap *bitmap = new NXWidgets::CRlePaletteBitmap(&g_nshBitmap);
- return static_cast<INxBitmap>(bitmap);
+ return static_cast<NXWidgets::IBitmap *>(bitmap);
}
@@ -63,14 +66,14 @@ CNxConsole::CNxConsole(NXWidgets::INxWindow *window)
* Get the icon associated with the application
*
- * @return An instance if INxBitmap that may be used to rend the
- * application's icon. This is an new INxBitmap instance that must
+ * @return An instance if IBitmap that may be used to rend the
+ * application's icon. This is an new IBitmap instance that must
* be deleted by the caller when it is no long needed.
*/